/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef _ACTIVEMQ_CONNECTOR_OPENWIRE_COMMANDS_MESSAGE_H_
#define _ACTIVEMQ_CONNECTOR_OPENWIRE_COMMANDS_MESSAGE_H_

// Turn off warning message for ignored exception specification
#ifdef _MSC_VER
#pragma warning( disable : 4290 )
#endif

#include <activemq/connector/openwire/commands/BaseCommand.h>
#include <activemq/connector/openwire/commands/ProducerId.h>
#include <activemq/connector/openwire/commands/ActiveMQDestination.h>
#include <activemq/connector/openwire/commands/TransactionId.h>
#include <activemq/connector/openwire/commands/ActiveMQDestination.h>
#include <activemq/connector/openwire/commands/MessageId.h>
#include <activemq/connector/openwire/commands/TransactionId.h>
#include <activemq/connector/openwire/commands/ActiveMQDestination.h>
#include <activemq/connector/openwire/commands/DataStructure.h>
#include <activemq/connector/openwire/commands/ConsumerId.h>
#include <activemq/connector/openwire/commands/BrokerId.h>
#include <vector>
#include <string>

namespace activemq{
namespace connector{
namespace openwire{
namespace commands{

    /*
     *
     *  Command and marshalling code for OpenWire format for ${className}
     *
     *
     *  NOTE!: This file is autogenerated - do not modify!
     *         if you need to make a change, please see the Java Classes
     *         in the activemq-openwire-generator module
     *
     */
    class Message : public BaseCommand
    {
    protected:

        ProducerId* producerId;
        ActiveMQDestination* destination;
        TransactionId* transactionId;
        ActiveMQDestination* originalDestination;
        MessageId* messageId;
        TransactionId* originalTransactionId;
        std::string groupID;
        int groupSequence;
        std::string correlationId;
        bool persistent;
        long long expiration;
        char priority;
        ActiveMQDestination* replyTo;
        long long timestamp;
        std::string type;
        std::vector<char> content;
        std::vector<char> marshalledProperties;
        DataStructure* dataStructure;
        ConsumerId* targetConsumerId;
        bool compressed;
        int redeliveryCounter;
        std::vector<BrokerId*> brokerPath;
        long long arrival;
        std::string userID;
        bool recievedByDFBridge;

    public:

        const static unsigned char ID_MESSAGE = 0;

    public:

        Message();
        virtual ~Message();

        /**
         * Get the unique identifier that this object and its own
         * Marshaller share.
         * @returns new DataStructure type copy.
         */
        virtual unsigned char getDataStructureType() const;

        /**
         * Clone this obbject and return a new instance that the
         * caller now owns, this will be an exact copy of this one
         * @returns new copy of this object.
         */
        virtual Message* clone() const;

        /**
         * Copy the contents of this object and place them into the
         * instance of this object type that was passed in.
         * @return dest - Destination Object
         */
        virtual void clone( Message* dest ) const;

        virtual const ProducerId* getProducerId() const;
        virtual ProducerId* getProducerId();
        virtual void setProducerId( ProducerId* producerId );

        virtual const ActiveMQDestination* getDestination() const;
        virtual ActiveMQDestination* getDestination();
        virtual void setDestination( ActiveMQDestination* destination );

        virtual const TransactionId* getTransactionId() const;
        virtual TransactionId* getTransactionId();
        virtual void setTransactionId( TransactionId* transactionId );

        virtual const ActiveMQDestination* getOriginalDestination() const;
        virtual ActiveMQDestination* getOriginalDestination();
        virtual void setOriginalDestination( ActiveMQDestination* originalDestination );

        virtual const MessageId* getMessageId() const;
        virtual MessageId* getMessageId();
        virtual void setMessageId( MessageId* messageId );

        virtual const TransactionId* getOriginalTransactionId() const;
        virtual TransactionId* getOriginalTransactionId();
        virtual void setOriginalTransactionId( TransactionId* originalTransactionId );

        virtual const std::string& getGroupID() const;
        virtual std::string& getGroupID();
        virtual void setGroupID( const std::string& groupID );

        virtual const int getGroupSequence() const;
        virtual int getGroupSequence();
        virtual void setGroupSequence( int groupSequence );

        virtual const std::string& getCorrelationId() const;
        virtual std::string& getCorrelationId();
        virtual void setCorrelationId( const std::string& correlationId );

        virtual const bool getPersistent() const;
        virtual bool getPersistent();
        virtual void setPersistent( bool persistent );

        virtual const long long getExpiration() const;
        virtual long long getExpiration();
        virtual void setExpiration( long long expiration );

        virtual const char getPriority() const;
        virtual char getPriority();
        virtual void setPriority( char priority );

        virtual const ActiveMQDestination* getReplyTo() const;
        virtual ActiveMQDestination* getReplyTo();
        virtual void setReplyTo( ActiveMQDestination* replyTo );

        virtual const long long getTimestamp() const;
        virtual long long getTimestamp();
        virtual void setTimestamp( long long timestamp );

        virtual const std::string& getType() const;
        virtual std::string& getType();
        virtual void setType( const std::string& type );

        virtual const std::vector<char> getContent() const;
        virtual std::vector<char> getContent();
        virtual void setContent( std::vector<char> content );

        virtual const std::vector<char> getMarshalledProperties() const;
        virtual std::vector<char> getMarshalledProperties();
        virtual void setMarshalledProperties( std::vector<char> marshalledProperties );

        virtual const DataStructure* getDataStructure() const;
        virtual DataStructure* getDataStructure();
        virtual void setDataStructure( DataStructure* dataStructure );

        virtual const ConsumerId* getTargetConsumerId() const;
        virtual ConsumerId* getTargetConsumerId();
        virtual void setTargetConsumerId( ConsumerId* targetConsumerId );

        virtual const bool getCompressed() const;
        virtual bool getCompressed();
        virtual void setCompressed( bool compressed );

        virtual const int getRedeliveryCounter() const;
        virtual int getRedeliveryCounter();
        virtual void setRedeliveryCounter( int redeliveryCounter );

        virtual const std::vector<BrokerId*> getBrokerPath() const;
        virtual std::vector<BrokerId*> getBrokerPath();
        virtual void setBrokerPath( std::vector<BrokerId*> brokerPath );

        virtual const long long getArrival() const;
        virtual long long getArrival();
        virtual void setArrival( long long arrival );

        virtual const std::string& getUserID() const;
        virtual std::string& getUserID();
        virtual void setUserID( const std::string& userID );

        virtual const bool getRecievedByDFBridge() const;
        virtual bool getRecievedByDFBridge();
        virtual void setRecievedByDFBridge( bool recievedByDFBridge );

    };

}}}}

#endif /*_ACTIVEMQ_CONNECTOR_OPENWIRE_COMMANDS_MESSAGE_H_*/

